@@ -1,6 +1,6 @@
 package Catmandu::Pure;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 1;
 __END__
@@ -14,13 +14,16 @@ Catmandu::Pure - A bundle of Catmandu modules for working with data from Pure
 =head1 SYNOPSIS
 
   # From the command line
-  $ catmandu convert Pure --base https://purehost/ws/rest --endpoint publication
+  $ catmandu convert Pure \
+        --base https://host/ws/api/... \
+        --endpoint research-outputs \
+        --apiKey "..."
 
 =head1 MODULES
 
 =over
 
-=item *
+=item
 
 L<Catmandu::Importer::Pure>
 
@@ -28,8 +31,9 @@ L<Catmandu::Importer::Pure>
 
 =head1 DESCRIPTION
 
-  Catmandu::Importer::Pure is a Catmandu package that seamlessly imports data from Elsevier's Pure system using its REST service.
-  Currently documentation describing the REST service can be found under /ws on a webserver that is running Pure.
+Catmandu::Importer::Pure is a Catmandu package that seamlessly imports data from Elsevier's Pure
+system using its REST service. Currently documentation describing the REST service can be found
+under /ws on a webserver that is running Pure.
 
 =head1 SEE ALSO
 
